@@ -81,15 +81,15 @@ class ApplicationService(BaseRdbmsService):
         owns this application.
 
 
-        :param app_id: Identification of a application to check whether the
+        @param app_id: Identification of a application to check whether the
             specified user is administrator of.
 
-        :param account_id: Identification of the account of a user to check
+        @param account_id: Identification of the account of a user to check
             whether he has the role of administrator for the specified
             application.
 
 
-        :raise IllegalAccessException: If the user specified by his account is
+        @raise IllegalAccessException: If the user specified by his account is
            not an administrator of the application.
         """
         application = self.get_application_with_id(app_id, check_status=True)
@@ -198,16 +198,16 @@ class ApplicationService(BaseRdbmsService):
             surfaced to client applications.
 
 
-        :param app_id: Identification of the application that accesses the service.
+        @param app_id: Identification of the application that accesses the service.
 
-        :param check_status: Indicate whether the function must check the
+        @param check_status: Indicate whether the function must check the
             current status of this application and raise an exception if it is
             not of enabled.
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: An object `RdbmsConnection`.
 
 
-        :return: An object containing the following members:
+        @return: An object containing the following members:
 
             * ``account_id``: Identification of the account of the user who
               registered this client application.
@@ -247,13 +247,13 @@ class ApplicationService(BaseRdbmsService):
               application has been modified, such as its name or its API keys.
 
 
-        :raise DeletedObjectException: If the application has been deleted,
+        @raise DeletedObjectException: If the application has been deleted,
             while the argument ``check_status`` has been set to ``True``.
 
-        :raise DisabledObjectException: If the application has been disabled,
+        @raise DisabledObjectException: If the application has been disabled,
             while the argument ``check_status`` has been set to ``True``.
 
-        :raise UndefinedObjectException: If the specified identification
+        @raise UndefinedObjectException: If the specified identification
             doesn't refer to a application registered against the platform.
         """
         # Retrieve the information of the application specified by its
@@ -325,18 +325,18 @@ class ApplicationService(BaseRdbmsService):
         Generate a new Application Programming Interface (API) key, which
         uniquely identifies this application.
 
-        :param account_id: Identification of the account of the user who
+        @param account_id: Identification of the account of the user who
            registers this application.  This account will own the API key that
            is issued.
 
-        :param name: The name of the application.
+        @param name: The name of the application.
 
-        :param picture_id: Identification of the logo of the application.
+        @param picture_id: Identification of the logo of the application.
 
-        :param platform: An item of `ApplicationPlatform` that describes the
+        @param platform: An item of `ApplicationPlatform` that describes the
             platform that this application runs on.
 
-        :param package: package name of the family this application belongs
+        @param package: package name of the family this application belongs
             to, if any defined. This allows to group under a same "branding
             umbrella" several applications that share the functionalities, the
             same users base. For instance, a software product can have a lite
@@ -345,13 +345,13 @@ class ApplicationService(BaseRdbmsService):
             notification to a user to whatever version(s) and platform(s) he
             could use.
 
-        :param stage: An item of `ApplicationStage` that indicates the
+        @param stage: An item of `ApplicationStage` that indicates the
             environment stage which the application is deployed onto.
 
-        :param team_id: Identification of a team this application belongs to.
+        @param team_id: Identification of a team this application belongs to.
 
 
-        :return: An object that contains the following members:
+        @return: An object that contains the following members:
 
             * ``app_id``: Identification of the application.
 
@@ -380,16 +380,16 @@ class ApplicationService(BaseRdbmsService):
               properties of this application.
 
 
-        :raise ApplicationNameAlreadyRegisteredException: If the name of the
+        @raise ApplicationNameAlreadyRegisteredException: If the name of the
             application to register is already used for an other application.
 
-        :raise DeletedObjectException: If the account of the user who registers
+        @raise DeletedObjectException: If the account of the user who registers
             this application has been deleted.
 
-        :raise DisabledObjectException: If the account of the user who
+        @raise DisabledObjectException: If the account of the user who
             registers this application has been disabled.
 
-        :raise UndefinedObjectException: If the argument ``account_id`` doesn't
+        @raise UndefinedObjectException: If the argument ``account_id`` doesn't
             refer to a user account registered to the platform.
         """
         with self.acquire_rdbms_connection(True) as connection:
@@ -576,31 +576,31 @@ class ApplicationService(BaseRdbmsService):
     #     Update some modifiable properties of the specified client application.
     #
     #
-    #     :param app_id: identification of the client application such as a Web,
+    #     @param app_id: identification of the client application such as a Web,
     #         a desktop, or a mobile application, that accesses the service.
     #
-    #     :param account_id: identification of the account of the user who is
+    #     @param account_id: identification of the account of the user who is
     #         updating the role of the member.  This first user MUST have a role
     #         of administrator.
     #
-    #     :param this_app_id: identification of the client application for which
+    #     @param this_app_id: identification of the client application for which
     #         some properties are updated.
     #
-    #     :param properties: a dictionary of properties of the specified client
+    #     @param properties: a dictionary of properties of the specified client
     #         application to be modified.
     #
     #
-    #     :raise DeletedObjectException: if the client application has been
+    #     @raise DeletedObjectException: if the client application has been
     #         deleted.
     #
-    #     :raise DisabledObjectException: if the client application has been
+    #     @raise DisabledObjectException: if the client application has been
     #         disabled.
     #
-    #     :raise IllegalAccessException: if the user on behalf of some
+    #     @raise IllegalAccessException: if the user on behalf of some
     #         properties of the client application are modified is not the agent
     #         or one of the regular administrators of this application.
     #
-    #     :raise UndefinedObjectException: if the specified identification
+    #     @raise UndefinedObjectException: if the specified identification
     #         doesn't refer to a client application registered to the platform.
     #     """
     #     with self.acquire_rdbms_connection(True) as connection:
@@ -661,13 +661,13 @@ class ApplicationService(BaseRdbmsService):
     #         surfaced to client applications.
     #
     #
-    #     :param name: name of the application to return information.
+    #     @param name: name of the application to return information.
     #
-    #     :param check_status: indicate whether the function must check the
+    #     @param check_status: indicate whether the function must check the
     #         current status of this user account and raise an exception if it is
     #         not of enabled.
     #
-    #     :return: an instance containing the following members:
+    #     @return: an instance containing the following members:
     #
     #         * ``account_id``: identification of the account of the user who
     #           registered this client application.
@@ -708,15 +708,15 @@ class ApplicationService(BaseRdbmsService):
     #           the name of the application, or the API keys, has been modified.
     #
     #
-    #     :raise DeletedObjectException: if the client application has been
+    #     @raise DeletedObjectException: if the client application has been
     #        deleted, while the argument ``check_status`` has been set to
     #        ``True``.
     #
-    #     :raise DisabledObjectException: if the client application has been
+    #     @raise DisabledObjectException: if the client application has been
     #        disabled, while the argument ``check_status`` has been set to
     #        ``True``.
     #
-    #     :raise UndefinedObjectException: if the specified name doesn't refer
+    #     @raise UndefinedObjectException: if the specified name doesn't refer
     #        to a client application registered against the platform.
     #     """
     #     with self.acquire_rdbms_connection() as connection:
@@ -759,13 +759,13 @@ class ApplicationService(BaseRdbmsService):
     #     developer, either as an administrator.
     #
     #
-    #     :param app_id: identification of the client application such as a Web,
+    #     @param app_id: identification of the client application such as a Web,
     #         a desktop, or a mobile application, that accesses the service.
     #
-    #     :param account_id: identification of a user account.
+    #     @param account_id: identification of a user account.
     #
     #
-    #     :return: a list of instances containing the following members:
+    #     @return: a list of instances containing the following members:
     #
     #         * ``account_id``: identification of the account of the user who
     #           registered this client application.
@@ -806,11 +806,11 @@ class ApplicationService(BaseRdbmsService):
     #           the name of the application, or the API keys, has been modified.
     #
     #
-    #     :raise DeletedObjectException: if the user account has been deleted.
+    #     @raise DeletedObjectException: if the user account has been deleted.
     #
-    #     :raise DisabledObjectException: if the user account has been disabled.
+    #     @raise DisabledObjectException: if the user account has been disabled.
     #
-    #     :raise UndefinedObjectException: if the specified identification
+    #     @raise UndefinedObjectException: if the specified identification
     #         doesn't refer to a user account registered against the platform.
     #     """
     #     AccountService().get_account(account_id, check_status=True)
