@@ -36,6 +36,7 @@ import uuid
 import zlib
 
 from majormode.perseus.constant import regex
+from majormode.perseus.constant.application import ApplicationStage
 from majormode.perseus.constant.http import HttpMethod
 from majormode.perseus.constant.http import HttpScheme
 from majormode.perseus.constant.http import REGEX_PATTERN_USER_AGENT
@@ -72,17 +73,17 @@ class HttpRequestLog:
         to the platform.
 
 
-        :param request: A `HttpRequest` instance.
+        @param request: A `HttpRequest` instance.
 
-        :param response: A `HttpResponse` instance.
+        @param response: A `HttpResponse` instance.
 
-        :param execution_duration: The time spent in processing the client's
+        @param execution_duration: The time spent in processing the client's
             HTTP request.
 
-        :param dispatch_duration: The time spent in sending the result to the
+        @param dispatch_duration: The time spent in sending the result to the
             client.
 
-        :param exception: A possible exception that the processing of this
+        @param exception: A possible exception that the processing of this
             HTTP request may have raised.
         """
         self.log_id = uuid.uuid1().hex
@@ -123,10 +124,10 @@ class HttpRequest:
             condition while handling a client's request.
 
 
-            :param message: A humanly-readable message that describes this
+            @param message: A humanly-readable message that describes this
                 exception instance.
 
-            :param payload: A JSON expression that provides detailed information
+            @param payload: A JSON expression that provides detailed information
                 about this exception instance.
             """
             super().__init__(message)
@@ -175,19 +176,19 @@ class HttpRequest:
             Build a new instance of this class.
 
 
-            :param field_name: Original field name in the form that has been sent
+            @param field_name: Original field name in the form that has been sent
                 to the platform to upload a file (cf. multipart MIME data
                 stream "multipart/form-data").
 
-            :param file_name: Name of the file as defined in the HTTP request that
+            @param file_name: Name of the file as defined in the HTTP request that
                 the client application sent to the platform.
 
-            :param content_type: Specify the nature of the data in the content of
+            @param content_type: Specify the nature of the data in the content of
                 the file that has been uploaded to the platform entity, by
                 giving type and subtype identifiers, and by providing auxiliary
                 information that may be required for certain types.
 
-            :param data: Content of the file that has been uploaded.
+            @param data: Content of the file that has been uploaded.
             """
             self._field_name = field_name
             self._file_name = file_name
@@ -228,35 +229,35 @@ class HttpRequest:
             Return the value of an argument contained in the JSON expression
 
 
-            :param payload: A JSON expression.
+            @param payload: A JSON expression.
 
-            :param argument_name: Name of the argument to return the value.
+            @param argument_name: Name of the argument to return the value.
 
-            :param default_value: default value to return if the argument was
+            @param default_value: default value to return if the argument was
                 optional and not defined within the HTTP request.
 
-            :param enumeration: An enumeration inheriting from `Enum`, when the
+            @param enumeration: An enumeration inheriting from `Enum`, when the
                 argument `data_type` is `ArgumentDataType.enumeration`.
 
-            :param is_required: Indicate whether this argument is mandatory, i.e.
+            @param is_required: Indicate whether this argument is mandatory, i.e.
                 it MUST be provided in the HTTP request, and if not provided, the
                 function will raise the exception `MissingArgumentException`.
 
-            :param item_data_type: When the argument to return the value is of
+            @param item_data_type: When the argument to return the value is of
                 data type `ArgumentType.list`, the caller can specify the data
                 type of the items that this list contains.
 
-            :param object_class: Python class to be used to instantiate a new
+            @param object_class: Python class to be used to instantiate a new
                 object from the JSON value of the given argument when the
                 specified data type of this argument is `object`.  This Python
                 class MUST implement a static method `from json` that returns an
                 instance of this class providing a JSON expression.
 
 
-            :return: The casted value of the argument.
+            @return: The casted value of the argument.
 
 
-            :raise MissingArgumentException: If the JSON expression doesn't
+            @raise MissingArgumentException: If the JSON expression doesn't
                 contain the specified argument while this argument is required.
             """
             if not isinstance(payload, dict):
@@ -284,10 +285,10 @@ class HttpRequest:
             Build an object with a JSON expression
 
 
-            :param payload: A JSON expression.
+            @param payload: A JSON expression.
 
 
-            :return: An object built from the JSON expression
+            @return: An object built from the JSON expression
             """
             raise NotImplementedError()
 
@@ -337,29 +338,29 @@ class HttpRequest:
         client application sent to the platform.
 
 
-        :note: The method `_prepare_` MUST be called to complete the
+        @note: The method `_prepare_` MUST be called to complete the
             instantiation of this object.
 
 
-        :param http_method: An instance `HttpMethod` that indicates the HTTP
+        @param http_method: An instance `HttpMethod` that indicates the HTTP
             method of this request.
 
-        :param uri: Uniform Resource Identifier that names a resource of the
+        @param uri: Uniform Resource Identifier that names a resource of the
             platform the HTTP request requires to gain access to.
 
-        :param arguments: A dictionary of key/value pairs representing the
+        @param arguments: A dictionary of key/value pairs representing the
             arguments passed in the query string of the HTTP request.
 
-        :param headers: A dictionary of key/value pairs representing the
+        @param headers: A dictionary of key/value pairs representing the
             headers of the HTTP request.
 
-        :param remote_ip: The Internet Protocol address of the client
+        @param remote_ip: The Internet Protocol address of the client
             application that initiates this HTTP request.
 
-        :param body: Content of the message body of the HTTP request when the
+        @param body: Content of the message body of the HTTP request when the
             HTTP method is `POST` or `PUT`.
 
-        :param uploaded_files: A list of instances `HttpRequestUploadedFile`
+        @param uploaded_files: A list of instances `HttpRequestUploadedFile`
             mapping the files that the client application has uploaded to
             the platform along the HTTP request.
         """
@@ -431,7 +432,7 @@ class HttpRequest:
     #     member `body`) of the HTTP request's message body into a JSON object
     #     when the content type has been indicated as of `application/json`.
     #
-    #     :raise Exception: if decompression issue occurs or if JSON string
+    #     @raise Exception: if decompression issue occurs or if JSON string
     #            representation is not conform to the JSON specification.
     #     """
     #     # Check whether the client application sends compressed request using
@@ -473,25 +474,25 @@ class HttpRequest:
         Convert a string to the specified data type.
 
 
-        :param argument_name: The name of the argument which value is casted.
+        @param argument_name: The name of the argument which value is casted.
             This parameter is only required for debugging purpose.
 
-        :param argument_value: The string to be converted to the specified
+        @param argument_value: The string to be converted to the specified
             data type.
 
-        :param argument_passing: An item of `HttpRequest.ArgumentPassing`
+        @param argument_passing: An item of `HttpRequest.ArgumentPassing`
             that indicates whether the argument value has been passed within
             the query parameters of the request or in the message body.  This
             parameter is only used to parse list of values.
 
-        :param data_type: An item of `HttpRequest.ArgumentDataType` that
+        @param data_type: An item of `HttpRequest.ArgumentDataType` that
             indicates the data type to cast the string to.
 
-        :param enumeration: A Python class inheriting from `Enum` which
+        @param enumeration: A Python class inheriting from `Enum` which
             the string MUST be an item of, when the argument `data_type` is
             `ArgumentDataType.string`.
 
-        :param object_class: A Python class to instantiate a new object from
+        @param object_class: A Python class to instantiate a new object from
             the JSON string representation, when the argument `data_type` is
             `object`.  This Python class MUST implement a static method
             `from_json` that returns an instance of this class providing a
@@ -501,20 +502,20 @@ class HttpRequest:
             `object`, the function uses the class `Object` to instantiate a
             new object from the JSON string representation
 
-        :param item_data_type: An item of `ArgumentDataType` that specifies
+        @param item_data_type: An item of `ArgumentDataType` that specifies
             the data type to cast each item of the list passed as argument,
             when `data_type` is `ArgumentDataType.list`.
 
 
-        :return: The value converted from the string with the specified data
+        @return: The value converted from the string with the specified data
             type.
 
 
-        :raise InvalidArgumentException: If `data_type` is
+        @raise InvalidArgumentException: If `data_type` is
             `ArgumentDataType.enumeration` but the argument `enumeration` has
             not be passed to this function.
 
-        :raise ValueError: If `argument_value` is not a valid string
+        @raise ValueError: If `argument_value` is not a valid string
             representation of the type specified in `data_type`.
         """
         if data_type == HttpRequest.ArgumentDataType.boolean:
@@ -604,9 +605,9 @@ class HttpRequest:
         Return the value of the HTTP request argument specified by its name.
 
 
-        :param name: name of the argument to return its value.
+        @param name: name of the argument to return its value.
 
-        :param argument_passing: An item of `ArgumentPassing` that indicates
+        @param argument_passing: An item of `ArgumentPassing` that indicates
             how this argument is passed with the HTTP request, within the
             query string or the message body.  The default argument passing
             depends on the HTTP method of the request:
@@ -623,41 +624,41 @@ class HttpRequest:
             function expects the message body to be a JSON dictionary, and the
             argument's name to be a root key of this dictionary.
 
-        :param data_type: data type of the value of this argument as one
+        @param data_type: data type of the value of this argument as one
             defined in the enumeration `HttpRequest.ArgumentDataType`.  The
             function might performs some check to ensure that the value of this
             argument corresponds to the specified data type.
 
-        :param default_value: default value to return if the argument was
+        @param default_value: default value to return if the argument was
             optional and not defined within the HTTP request.
 
-        :param enumeration: An enumeration inheriting from `Enum`, when the
+        @param enumeration: An enumeration inheriting from `Enum`, when the
             argument `data_type` is `ArgumentDataType.enumeration`.
 
-        :param is_required: Indicate whether this argument is mandatory, i.e.
+        @param is_required: Indicate whether this argument is mandatory, i.e.
             it MUST be provided in the HTTP request, and if not provided, the
             function will raise the exception `MissingArgumentException`.
 
-        :param item_data_type: When the argument to return the value is of
+        @param item_data_type: When the argument to return the value is of
             data type `ArgumentType.list`, the caller can specify the data
             type of the items that this list contains.
 
-        :param object_class: Python class to be used to instantiate a new
+        @param object_class: Python class to be used to instantiate a new
             object from the JSON value of the given argument when the
             specified data type of this argument is `object`.  This Python
             class MUST implement a static method `from json` that returns an
             instance of this class providing a JSON expression.
 
 
-        :return: the value of the specified argument as passed with the HTTP
+        @return: the value of the specified argument as passed with the HTTP
             request.
 
 
-        :raise InvalidMessageBodyException: if the HTTP method is `POST` or
+        @raise InvalidMessageBodyException: if the HTTP method is `POST` or
             `PUT`, but the message body of this request is either empty or it
             is not a valid JSON expression.
 
-        :raise MissingArgumentException: if no argument corresponds to the
+        @raise MissingArgumentException: if no argument corresponds to the
             specified name while this argument is required.
         """
         # Determine the argument passing when not specified, depending on the
@@ -733,32 +734,32 @@ class HttpRequest:
         """
         Return the field value of the HTTP header specified by its field name.
 
-        :param field_name: name of the HTTP header's field.
+        @param field_name: name of the HTTP header's field.
 
-        :param data_type: data type of the value of this argument as one
+        @param data_type: data type of the value of this argument as one
            defined in the enumeration `HttpRequest.ArgumentDataType`.  The
            function performs some checks to ensure that the value of this
            argument corresponds to the specified data type.
 
-        :param default_value: default value to return if the header was
+        @param default_value: default value to return if the header was
            optional and not defined within the HTTP request.
 
-        :param enumeration: An enumeration inheriting from `Enum`, when the
+        @param enumeration: An enumeration inheriting from `Enum`, when the
             argument `data_type` is `ArgumentDataType.enumeration`.
 
-        :param is_required: Indicate whether this header is mandatory, i.e.
+        @param is_required: Indicate whether this header is mandatory, i.e.
             it MUST be provided in the HTTP request, and if not provided, the
             function will raise the exception `MissingHeaderException`.
 
-        :param item_data_type: When the header to return the value is of
+        @param item_data_type: When the header to return the value is of
             data type `ArgumentType.list`, the caller can specify the data
             type of the items that this list contains.
 
 
-        :return: the value of the HTTP header's field.
+        @return: the value of the HTTP header's field.
 
 
-        :raise MissingHeaderException: the specified field name doesn't
+        @raise MissingHeaderException: the specified field name doesn't
                correspond to any HTTP header defined in this request.
         """
         if field_name not in self.headers:
@@ -858,7 +859,7 @@ class HttpMethodSpec:
         Build a new instance of `HttpMethodSpec`.
 
 
-        :param http_method: One of the supported HTTP 1.1 common methods as
+        @param http_method: One of the supported HTTP 1.1 common methods as
            defined in the enumeration `HttpMethod` of the class `HttpRequest`:
 
            * `HttpMethod.DELETE`
@@ -870,17 +871,17 @@ class HttpMethodSpec:
            * `HttpMethod.PUT`
 
 
-        :param uri_pattern: Uniform Resource Identifier (URI) pattern (i.e.,
+        @param uri_pattern: Uniform Resource Identifier (URI) pattern (i.e.,
             a regular expression) that the wrapped method is responsible to
             handle.
 
-        :param handler_module_name: Name of the Python module that contains
+        @param handler_module_name: Name of the Python module that contains
             the code of the HTTP request handler.
 
-        :param handler_class_name: Name of the Python class that implements
+        @param handler_class_name: Name of the Python class that implements
             the HTTP request handler.
 
-        :param handler_method: The Python function that handles the URI
+        @param handler_method: The Python function that handles the URI
             pattern.  This function MUST be a method of a class inheriting
             from `HttpRequestHandler`; because, at the time a function is
             defined, it is just a plain function, i.e., it is not bound to any
@@ -888,14 +889,14 @@ class HttpMethodSpec:
             checked.
 
 
-        :raise AlreadyDeclaredURLBitException: if an URL bit is declared more
+        @raise AlreadyDeclaredURLBitException: if an URL bit is declared more
             than one time in the specified Uniform Resource Identifier (URI)
             pattern.
 
-        :raise AssertError: If the argument `http_method` is not an item of
+        @raise AssertError: If the argument `http_method` is not an item of
             the enumeration `HttpMethod`.
 
-        :raise UnsupportedURLBitDataTypeException: If an in-line parameter
+        @raise UnsupportedURLBitDataTypeException: If an in-line parameter
             (i.e., URL bits), declared in the Uniform Resource Identifier (URI)
             pattern, has a data type that is not supported.
         """
@@ -934,17 +935,17 @@ class HttpMethodSpec:
         to the matching regular expression.
 
 
-        :param uri_pattern: Uniform Resource Identifier (URI) pattern (i.e.,
+        @param uri_pattern: Uniform Resource Identifier (URI) pattern (i.e.,
             a regular expression) that the wrapped method is responsible to
             handle.
 
-        :param handler_module_name: Name of the Python module that contains
+        @param handler_module_name: Name of the Python module that contains
             the code of the HTTP request handler.
 
-        :param handler_class_name: Name of the Python class that implements
+        @param handler_class_name: Name of the Python class that implements
             the HTTP request handler.
 
-        :param handler_method: The Python function that handles the URI
+        @param handler_method: The Python function that handles the URI
             pattern.  This function MUST be a method of a class inheriting
             from `HttpRequestHandler`; because, at the time a function is
             defined, it is just a plain function, i.e., it is not bound to any
@@ -952,7 +953,7 @@ class HttpMethodSpec:
             checked.
 
 
-        :return: the URI pattern with URL bits declared as named groups with
+        @return: the URI pattern with URL bits declared as named groups with
             their respective data type converted to regular expressions, and a
             dictionary of the URL bits and their respective data type (item of
             `HttpRequest.ArgumentDataType`).
@@ -1039,10 +1040,10 @@ class HttpMethodSpec:
         Indicate whether this instance is equivalent to another.
 
 
-        :param other: Another instance of the class `HttpMethodSpec`.
+        @param other: Another instance of the class `HttpMethodSpec`.
 
 
-        :return: `True` if the two instances are equivalent; `False` otherwise.
+        @return: `True` if the two instances are equivalent; `False` otherwise.
         """
         return isinstance(other, HttpMethodSpec) and \
             self.http_method == other.http_method and \
@@ -1053,7 +1054,7 @@ class HttpMethodSpec:
         Return the hash value of the HTTP endpoint method.
 
 
-        :return: An integer corresponding to the hash value of the HTTP
+        @return: An integer corresponding to the hash value of the HTTP
             endpoint method.
         """
         return hash((self.http_method, self.uri_pattern))
@@ -1064,10 +1065,10 @@ class HttpMethodSpec:
         providing a HTTP request sent by a client application
 
 
-        :param request: An instance of `HttpRequest`.
+        @param request: An instance of `HttpRequest`.
 
 
-        :return: The result returned by the handler that processed this
+        @return: The result returned by the handler that processed this
             request.
         """
         # Load the Python module of the handler if not already done.
@@ -1142,7 +1143,7 @@ class HttpResponse:
             processed the HTTP request.
 
 
-            :param exception: The inner exception raised by the handler method of
+            @param exception: The inner exception raised by the handler method of
                 a RESTful API service that processed the HTTP request.
             """
             self.error = exception.__class__.__name__
@@ -1156,7 +1157,7 @@ class HttpResponse:
         processed this request.
 
 
-        :param result: result returned by the RESTful API service method that
+        @param result: result returned by the RESTful API service method that
             has processed a HTTP request.
         """
         # Convert the result to an empty dictionary if the result is null, or
@@ -1173,7 +1174,7 @@ class HttpResponse:
         request.
 
 
-        :return: A string representation of the JSON expression of the result.
+        @return: A string representation of the JSON expression of the result.
         """
         return json.dumps(obj.stringify(self._result, trimmable=True))
 
@@ -1184,11 +1185,11 @@ class HttpResponse:
         a HTTP request.
 
 
-        :param exception: An exception raised by the RESTful API service
+        @param exception: An exception raised by the RESTful API service
             method that has processed a HTTP request that failed.
 
 
-        :return: An instance `HttpResponse` that embeds an instance
+        @return: An instance `HttpResponse` that embeds an instance
             `HttpResponseException` built with the inner exception raised by
             the RESTful API service method that has processed a HTTP request.
         """
@@ -1205,7 +1206,7 @@ def get_logger():
     application's settings.
 
 
-    :return: an instance `Logger`.
+    @return: an instance `Logger`.
     """
     return logging.getLogger(getattr(settings, 'LOGGER_NAME'))
 
@@ -1247,33 +1248,33 @@ def http_request(
         communicating with.
 
 
-    :param uri_pattern: Uniform Resource Identifier (URI) pattern,
+    @param uri_pattern: Uniform Resource Identifier (URI) pattern,
         corresponding to a regular expression, the wrapped method is
         responsible to handle.
 
-    :param http_method: An item of the enumeration `HttpMethod`.  The
+    @param http_method: An item of the enumeration `HttpMethod`.  The
         selected HTTP method indicates the desired action to be performed
         on the resource identified by the URI.  What this resource
         represents depends on the implementation of the method wrapped.
 
-    :param authentication_required: Indicate whether the wrapped method
+    @param authentication_required: Indicate whether the wrapped method
         requires the user, on behalf of whom the HTTP request is sent, to
         be authenticated or not.  If `True`, the client application MUST
         provide the HTTP header field `X-Authentication`, passing the
         identification of the login session of this user.
 
-    :param compatibility_required: Indicate whether the wrapped method
+    @param compatibility_required: Indicate whether the wrapped method
         requires the client application to be strictly compatible with
         the version of the RESTful API application's.  If `True`, the
         client application MUST provide the HTTP header field
         `X-API-Version` which value MUST comply with a version number
         using a standard tuple of integers: `major.minor.patch`.
 
-    :param json_data: Indicate whether the message body of HTTP methods
+    @param json_data: Indicate whether the message body of HTTP methods
         such as `POST` and `PUT` MUST be a string representation of a
         JSON expression.
 
-    :param sensitive_data: Indicate whether sensitive data could be
+    @param sensitive_data: Indicate whether sensitive data could be
         transmitted back and forth among the HTTP request or its response
         between the client application and the RESTful API application.
 
@@ -1294,17 +1295,17 @@ def http_request(
         returned by the RESTful API application, for environment stages
         other than development, integration, and test.
 
-    :param signature_required: indicate whether the wrapped method
+    @param signature_required: indicate whether the wrapped method
         requires the HTTP request to be signed with the Secret Key tied
         with the Consumer Key of the client application that sent this
         request.  If `True`, the client application MUST provide the
         HTTP header fields `X-API-Key` and `X-API-Sig`.
 
 
-    :return: A function that decorates the given method.
+    @return: A function that decorates the given method.
 
 
-    :raise Exception: If some unexpected conditions occurred while
+    @raise Exception: If some unexpected conditions occurred while
         decorating the HTTP request handler, such as the URI pattern has
         been already registered with another method, or some options
         passed to this decorator have incoherent values, etc.
@@ -1365,9 +1366,10 @@ def http_request(
         # Check coherence of the options passed to the decorator.
         if authentication_required and not signature_required:
             logger = get_logger()
-            logger.error('Method {}.{}.{} requires authentication without signature'.format(
-                method.__module__, class_name, method.__name__))
-            raise Exception('Signature MUST be requested when authentication is required')
+            logger.error(
+                f"Method {method.__module__}.{class_name}.{method.__name__} requires authentication without signature"
+            )
+            raise Exception("Signature MUST be requested when authentication is required")
 
         # Register the specified class method to handle the specified HTTP
         # method for the given Uniform Resource Identifier (URI).
@@ -1427,25 +1429,25 @@ def get_account_session(request, app_id, authentication_required):
     sent to the RESTful API server.
 
 
-    :param request: An instance `HttpRequest`.
+    @param request: An instance `HttpRequest`.
 
-    :param app_id: Identification of the client application.
+    @param app_id: Identification of the client application.
 
-    :param authentication_required: Indicate whether the wrapped method
+    @param authentication_required: Indicate whether the wrapped method
         requires the user, on behalf of whom the HTTP request is sent, to
         be authenticated or not.  If `True`, the client application MUST
         provide the HTTP header field `X-Authentication`, passing the
         identification of the login session of this user.
 
 
-    :return: An instance `Session` if the user is authenticated against
+    @return: An instance `Session` if the user is authenticated against
         the RESTful API server, `None` otherwise.
 
 
-    :raise ExpiredSessionException: if the account session of the user has
+    @raise ExpiredSessionException: if the account session of the user has
         expired.  The user needs to login again.
 
-    :raise MissingHeaderException: If the request requires the user, on
+    @raise MissingHeaderException: If the request requires the user, on
         behalf of whom the HTTP request is sent, to be authenticated while
         the client application didn't pass the HTTP header
         `X-Authentication`.
@@ -1465,9 +1467,9 @@ def get_client_application_info(request, compatibility_required):
     application that sent a HTTP request to the RESTful API server.
 
 
-    :param request: An instance `HttpRequest`.
+    @param request: An instance `HttpRequest`.
 
-    :param compatibility_required: Indicate whether the wrapped method
+    @param compatibility_required: Indicate whether the wrapped method
         requires the client application to be strictly compatible with
         the version of the RESTful API application's.  If `True`, the
         client application MUST provide the HTTP header field
@@ -1475,7 +1477,7 @@ def get_client_application_info(request, compatibility_required):
         using a standard tuple of integers: `major.minor.patch`.
 
 
-    :return: A named tuple `(client_api_version, client_application)`
+    @return: A named tuple `(client_api_version, client_application)`
         where:
 
         * `client_api_version`: An instance `Version` that represents the
@@ -1486,7 +1488,7 @@ def get_client_application_info(request, compatibility_required):
           HTTP request, or `None` if the application is not identified.
 
 
-    :raise HttpRequest.DeprecatedApiException: If API version
+    @raise HttpRequest.DeprecatedApiException: If API version
         compatibility is required while the client application has
         integrated a version of the RESTful API older than the one
         currently deployed.
@@ -1522,16 +1524,16 @@ def get_request_application_id(request, signature_required):
     HTTP request.
 
 
-    :param request: An instance `HttpRequest`.
+    @param request: An instance `HttpRequest`.
 
-    :param signature_required: indicate whether the wrapped method
+    @param signature_required: indicate whether the wrapped method
         requires the HTTP request to be signed with the Secret Key tied
         with the Consumer Key of the client application that sent this
         request.  If `True`, the client application MUST provide the
         HTTP header fields `X-API-Key` and `X-API-Sig`.
 
 
-    :return: identification of the RESTful API application the HTTP
+    @return: identification of the RESTful API application the HTTP
         request is sent to.
     """
     # When a RESTful API application is deployed on a development or an
@@ -1555,10 +1557,20 @@ def get_request_application_id(request, signature_required):
     consumer_key = request.get_header('X-API-Key', data_type=HttpRequest.ArgumentDataType.hexadecimal)
     client_signature = request.get_header('X-API-Sig', is_required=signature_required)
 
+    app_info = ApplicationService().get_application_with_consumer_key(consumer_key, check_status=True)
+
+    # Check whether the HTTP request signature is required.
+    if app_info.stage == ApplicationStage.live and client_signature is None:
+        raise ApplicationService.IncorrectSignatureException('Undefined HTTP request signature')
+
     if signature_required or client_signature:
-        return ApplicationService().validate_signature(
-            consumer_key,
+        message_body = request.raw_body if request.headers.get('Content-Type').startswith('application/json') else None
+
+        ApplicationService().validate_signature(
+            app_info,
             request.uri,
-            request.raw_body if request.headers.get('Content-Type').startswith('application/json') else None,
-            client_signature,
-            strict=signature_required)
+            message_body,
+            client_signature
+        )
+
+    return app_info.app_id
